#
# spec file for package intel-cmt-cat
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Intel Corporation
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           intel-cmt-cat
Version:        2.0.0
Release:        lp152.4.8
Summary:        Provides command line interface to CMT, MBM, CAT and CDP technologies
License:        BSD-3-Clause
Group:          Development/Tools/Other
Url:            https://github.com/01org/%{name}
# https://github.com/01org/intel-cmt-cat/archive/v1.0.1.tar.gz
Source0:        %{name}-%{version}.tar.gz
Patch1:         fix-bad-env-shebang.patch
BuildRequires:  doxygen
ExclusiveArch:  x86_64 i686 i586

# Since they ship libpqos and the binaries in one package but do not simultatious
# updates libversion can differ from binaries version.

%global make_flags EXTRA_CFLAGS="%{optflags}" SHARED=y PREFIX=%{buildroot}/%{_prefix} MAN_DIR=%{buildroot}/%{_mandir}/man8 LIB_INSTALL_DIR=%{buildroot}%{_libdir}/

%description
This software package provides basic support for
Cache Monitoring Technology (CMT), Memory Bandwidth Monitoring (MBM),
Cache Allocation Technology (CAT) and Code Data Prioratization (CDP).

CMT, MBM and CAT are configured using Model Specific Registers (MSRs)
to measure last level cache occupancy, set up the class of service masks and
manage the association of the cores/logical threads to a class of service.
The software executes in user space, and access to the MSRs is
obtained through a standard Linux* interface. The virtual file system
provides an interface to read and write the MSR registers but
it requires root privileges.

%package     -n libpqos2
Version:        2.0.0
Release:        lp152.4.8
Summary:        Runtime qpos library
Group:          System/Libraries

%description -n libpqos2
PQoS library provides API to detect and configure Intel(R) RDT including:
Cache Monitoring Technology (CMT), Memory Bandwidth Monitoring (MBM),
Cache Allocation Technology (CAT), Code and Data Prioritization (CDP) Technology.

%package     -n libpqos-devel
Version:        2.0.0
Release:        lp152.4.8
Summary:        Development package for libpqos2
Group:          Development/Libraries/C and C++
Requires:       libpqos2 = %version
Obsoletes:      libpqos1-devel < %version
Provides:       libpqos1-devel = %version

%description    -n libpqos-devel
PQoS library provides API to detect and configure Intel(R) RDT including:
Cache Monitoring Technology (CMT), Memory Bandwidth Monitoring (MBM),
Cache Allocation Technology (CAT), Code and Data Prioritization (CDP) Technology.

This package contains all that is needed to develop/compile
applications that use PQoS.

%prep
%setup
%patch1 -p1

%build
make %{?_smp_mflags} %{make_flags}

%install
make %{make_flags} NOLDCONFIG=y install

%post -n libpqos2 -p /sbin/ldconfig

%postun -n libpqos2 -p /sbin/ldconfig

%files
%defattr(-, root, root, -)
%doc LICENSE ChangeLog
%{_bindir}/pqos
%{_mandir}/man8/pqos.8.gz
%{_bindir}/rdtset
%{_mandir}/man8/rdtset.8.gz
%{_bindir}/pqos-msr
%{_mandir}/man8/pqos-msr.8.gz
%{_bindir}/pqos-os
%{_mandir}/man8/pqos-os.8.gz

%files -n libpqos-devel
%defattr(-, root, root, -)
%{_includedir}/pqos.h
%{_libdir}/*.so

%files     -n libpqos2
%defattr(-, root, root, -)
%{_libdir}/*.so.*

%changelog
* Fri Sep 14 2018 trenn@suse.de
- libpqos-devel must obsolete libpqos1-devel since last change
* Tue Sep 11 2018 trenn@suse.de
- Rename libpqos2-devel to libpqos-devel.
  Library devel package must not include library version in name
* Tue Sep  4 2018 trenn@suse.de
- Update to version 2.0.0
  Bump up libpqos1 package version to libpqos2
- Remove ldconfig patch and use NOLDCONFIG Makefile variable
  D    fix-ldconfig-call.patch
- Do not use env in shebang to avoid osc errors:
  A    fix-bad-env-shebang.patch
  From mainline Changelog:
  1. Library
  - Added support for resctrl monitoring via OS interface
  - Added support for PID group monitoring
  - Added support for L2 CDP
  - New API added for adding/removing pids to mon groups
  2. PQoS Utility
  - Added support for PID group monitoring
  - Added support for L2 CDP
  - Print core values in PID monitoring output
  3. rdtset Utility
  - Added support for L2 CDP
* Thu Mar  1 2018 trenn@suse.de
- Update to version 1.1.0 (fate#322856):
  1. Library
  - Added support for MBA configuration via OS interface
  2. PQoS Utility
  - Added better feature enumeration functionality
  - Added top-pids monitoring functionality
- Change group declaration in spec file from
  Development/Tools
  to
  Development/Tools/Other
  to avoid invalid group build service warning.
- Adding _service file for easier version upgrades
  Replacing the libversion variable in spec file with the real
  version, so that automated version upgrades via service feature
  works.
* Fri Aug  4 2017 trenn@suse.de
- Update to version 1.1.0 (fate#322856):
  1. Library
  - Added PID support for L2CAT, L3CAT and CDP
  - Added global RDT interface enforcement.
  2. PQoS Utility
  - Added PID support for L2CAT, L3CAT and CDP
  3. rdtset Utility
  - Added PID support for L2CAT, L3CAT and CDP
  - Updated to work with multiple PID's
  D    fix-dynlib-generation.patch
  D    fixsymlink.patch
* Thu Jul 13 2017 bwiedemann@suse.com
- Update to version 1.0.1:
    snmp
  - Added OS interface support to Net-SNMP sub-agent
    General
  - Build improvements (boo#1041090)
  - Bug fixes
    Library
  - Removed NO_PID_API compile time option
  - Added OS interface to support L3/L2 CAT & CDP
  - Updated support for CMT per PID
    PQoS Utility
  - Added pqos-os & pqos-msr wrapper scripts
  - Added option to select OS or MSR interface
    rdtset Utility
  - Added option to select OS or MSR interface
    Examples
  - Support for new OS/MSR interface added to CMT/MBM examples
- Add fixsymlink.patch to create proper man page symlinks
- Rebase fix-dynlib-generation.patch
* Tue Mar  7 2017 fschnizlein@suse.de
- Fixes bsc#990230 (if submitted and accepted in factory)
- Renamed intel-cmt-cat-devel to libqpos0-devel
- Removed obsolete patches due Makefile restructuring
  D intel-cmt-cat-DESTDIR.patch
  D intel-cmt-cat-Makefile.patch
  D intel-cmt-cat-dynlib.patch
- Added patches to build library correctly
  A fix-dynlib-generation.patch
  A fix-ldconfig-call.patch
- Added _service file
- Update to version 0.1.5-1:
  * Added MBA get to library.
  * MBA added to pqos tool show configuration option
  * Added mba -e option to pqos
  * MBA added to allocation reset function
  * Updated changelog, pqos help menu and man page with L2 CAT per cluster and MBA changes.
  * Added 11 LLC ways configuration files for pqos
  * Added profile with 11 cache ways
  * Corrected detection of MBM capabilities
  * Updated pqos utility error message for when no allocation resource ID is specified.
  * Modified pqos_pid_start API to only set single bit in event mask when starting remote memory B/W monitoring using perf. Moved remote memory monitor dependences to RMEM section.
* Thu Dec  1 2016 trenn@suse.de
- Initial package
- split off -devel and lib package.
- Patches added:
  * Makefile_include.patch
  * Makefile_ldconfig.patch
